 /*-----------------------------------------------------------------*
  |     Name: catberk2.sas                                          |
  |    Title: CATPLOT demo: Berkeley Admission Data                 |
  | ----------------------------------------------------------------|
  |    Procs: format catmod print                                   |
  |   Macros: pscale catplot gskip                                  |
  | Datasets: berkeley                                              |
  | ----------------------------------------------------------------|
  |   Author: Michael Friendly <friendly@yorku.ca>                  |
  |  Created: 26 Apr 2000 15:18:20                                  |
  *-----------------------------------------------------------------*/
title 'CATPLOT demo: Berkeley Admission Data';
%include goptions;
*include macros(catplot);
*include macros(pscale);
*include macros(gskip);
goptions vsize=6.2 in hsize=7 in  htext=1.6;

proc format;
   value dept  1="A" 2="B" 3="C" 4="D" 5="E" 6="F";
data berkeley;
   do dept = 'A','B','C','D','E','F';
      do gender = 'Male  ', 'Female';
         do admit = 'Admit ', 'Reject';
            input freq @@;
            output;
   end; end; end;
         /* Admit Not */
cards;
     512  313    89   19
     353  207    17    8
     120  205   202  391
     138  279   131  244
      53  138    94  299
      22  351    24  317
;
title h=1.8 'Berkeley Admissions Data';
proc catmod order=data
            data=berkeley;
*  format dept dept. ;
   population dept gender;
   weight freq;
   response / out=predict;
   model admit = dept  / ml noiter noprofile title='Model (AD, DG)';
run;

*-- Generate probability scale for right v axis; 
%pscale(lo=-4, hi=3, anno=pscale, prob=%str(0.05,.1,.25,.5,.75,.9));

axis1 order=(-3 to 2) offset=(4)
      label=(a=90 'Log Odds (Admitted)');
axis2 label=('Department') offset=(4);
title h=1.9 'Berkeley Admissions Data'
		h=1.5 a=-90 'Probability (Admitted)'
      h=3.0 a=-90 ' ';
title2 h=1.6 'Observed and Fitted Logits (95% CI)';
title3 h=1.6 'Model:  logit(Admit) = Dept';
legend1 position=(bottom inside left)  offset=(4,3)
        mode=share
        cborder=blue
        across=1
        shape=symbol(6,1.5)
        label=('Gender')
        value=(c=black 'Female'
               c=red   'Male');
symbol1 i=none v=circle h=1.7 c=black;
symbol2 i=none v=dot    h=1.7 c=red  ;
%catplot(data=predict, class=gender, xc=dept, z=1.96, anno=pscale,
         legend=legend1);
%gskip;
 
proc catmod order=data
            data=berkeley;
   weight freq;
   response / out=predict;
   model admit = dept gender / ml noiter noprofile ;
  run;
proc print data=predict;
  id dept gender admit _type_;
  var _obs_ _pred_ _sepred_;
  format _numeric_  6.3;

%pscale(lo=-4, hi=3, anno=pscale, prob=%str(0.05,.1,.25,.5,.75,.9));

title h=1.6 'Model:  logit(Admit) = Dept Gender'
		      a=-90 'Probability (Admitted)'
      h=3.5 a=-90 ' ';
legend1 position=(bottom inside left)  offset=(4,3)
        mode=share cborder=blue across=1
        shape=symbol(6,1.5) label=('Gender')
        value=(c=black 'Female'
               c=red   'Male');
axis1 order=(-3 to 2) offset=(4)
      label=(a=90 'Log Odds (Admitted)');
axis2 label=('Department') offset=(4);
symbol1 i=none v=circle h=1.7 c=black;
symbol2 i=none v=dot    h=1.7 c=red  ;
%catplot(data=predict, class=gender, xc=dept, type=FUNCTION,
	z=1.96, anno=pscale, legend=legend1);

